@@ -12,14 +12,14 @@ class UserAwareCrudSchema(CrudSchema):
                 code=-1, status=HttpStatus.HTTP_405_METHOD_NOT_ALLOWED, field_name='USER_FIELD',
                 message='USER_FIELD missing', description='USER_FIELD missing')
 
-        super(UserAwareCrudSchema, self).__init__(*args, **kwargs)
         self.user = user
+        super(UserAwareCrudSchema, self).__init__(*args, **kwargs)
         print(f'USER: {self.user}')
 
-        if not isinstance(self.MODEL_CLASS, BaseTrackedModel):
-            raise Error(
-                code=-1, status=HttpStatus.HTTP_405_METHOD_NOT_ALLOWED, field_name='MODEL_CLASS',
-                message='Class must be of type BaseTrackedModel', description='Class must be of type BaseTrackedModel')
+        # if not isinstance(self.MODEL_CLASS, BaseTrackedModel): TODO
+        #     raise Error(
+        #         code=-1, status=HttpStatus.HTTP_405_METHOD_NOT_ALLOWED, field_name='MODEL_CLASS',
+        #         message='Class must be of type BaseTrackedModel', description='Class must be of type BaseTrackedModel')
 
     def set_queryset(self, filters):
         filters[self.USER_FIELD] = self.user
