@@ -78,31 +78,31 @@ class BaseView(View):
 class BaseCrudView(BaseView):
 
     def get(self, request, filters, **kwargs):
-        crud = self.schema_class(filters, **kwargs.pop('initkwargs', {}))
+        crud = self.schema_class(filters=filters, **kwargs.pop('initkwargs', {}))
         self.data = crud.get()
         return self._respond()
 
     def post(self, request, filters, **kwargs):
         print('in post')
-        crud = self.schema_class(filters, **kwargs.pop('initkwargs', {}))
+        crud = self.schema_class(filters=filters, **kwargs.pop('initkwargs', {}))
         body = unjsonize(request.body.decode())
         self.data = crud.post(**body, **kwargs)
         return self._respond()
 
     def bulk_post(self, request, filters, **kwargs):
-        crud = self.schema_class(filters, **kwargs.pop('initkwargs', {}))
+        crud = self.schema_class(filters=filters, **kwargs.pop('initkwargs', {}))
         body = unjsonize(request.body.decode())
         self.data = crud.bulk_post(data=body, **filters, **kwargs)
         return self._respond()
 
     def put(self, request, filters, **kwargs):
-        crud = self.schema_class(filters, **kwargs.pop('initkwargs', {}))
+        crud = self.schema_class(filters=filters, **kwargs.pop('initkwargs', {}))
         body = unjsonize(request.body.decode())
         self.data = crud.put(**body, **kwargs)
         return self._respond()
 
     def delete(self, request, filters, **kwargs):
-        crud = self.schema_class(filters, **kwargs.pop('initkwargs', {}))
+        crud = self.schema_class(filters=filters, **kwargs.pop('initkwargs', {}))
         if not crud.delete():
             return HttpResponse(status=404)
         return self._respond()
