@@ -14,10 +14,6 @@ from .lookups import ChoicesView
 
 
 class _SetUserCrudView(BaseCrudView):
-    def __init__(self, *args, **kwargs):
-        super(_SetUserCrudView, self).__init__(*args, **kwargs)
-        self.user = None
-
     def get(self, request, *args, **kwargs):
         return super(_SetUserCrudView, self).get(
             request=request, initkwargs=dict(user=request.resource_owner), *args, **kwargs)
